<!--
File Name:			teamMemberOverview.xql
Request Name:		"getTeamMemberOverview"

Used:					Team Member Overview Page
Incoming Params:	PRTeam.prID as id
-->

<niku:template xmlns:niku="http://www.niku.com/xql">
   
   <niku:custom name="teamMemberHandler" class="com.niku.projmgr.xql.handlers.TeamMemberHandler"/>
	<niku:function name="hasRecords" class="com.niku.projmgr.xql.functions.HasRecords"/>

<!--
<niku:debug value="teamMemberOverview() S T A R T... id({$id}) projectID({$projectID}) projectId({$projectId}) projectid({$projectid})"/>
-->

   <niku:sql name="team">
      SELECT   * 
      FROM     PRTeam
      WHERE    prID={$id}
   </niku:sql>
   
   <niku:if test="{hasRecords('team')}">
      <niku:else>
         <ERROR>
            <NO_DATA error="1006_DATA_NOT_FOUND" Type="No Data" />
         </ERROR>
      </niku:else>
      
      <niku:include href="enableAdvResReqs.xql"/>
         
         <niku:for-each select="team">

            <niku:sql name="project">
               SELECT   *
               FROM     PRProject
               WHERE    prID = {@prProjectID}
            </niku:sql>

            <!-- check to see if the project is a fast plan -->
            <niku:sql name="effort_task">
               SELECT prID, prExternalID
               FROM   PRTask
               WHERE  prProjectID = {@team.prProjectID}
               AND    prExternalID = '~rmw'
            </niku:sql>
         
            <niku:for-each select="effort_task">
               <niku:variable name="bottomUpMode" value="{@effort_task.prExternalID}"/>
            </niku:for-each>      

            <!-- want EMAIL, but need old names for doh/dot for buried handler function -->
            <niku:sql name="resource">
               SELECT   PRJ_RESOURCES.*,
                        SRM_RESOURCES.ID,
                        SRM_RESOURCES.FULL_NAME,
                        SRM_RESOURCES.DATE_OF_HIRE AS prDOH,
                        SRM_RESOURCES.DATE_OF_TERMINATION AS prDOT,
                        SRM_RESOURCES.IS_ACTIVE,
                        SRM_RESOURCES.RESOURCE_TYPE,
                        SRM_RESOURCES.EMAIL
               FROM     PRJ_RESOURCES, SRM_RESOURCES
               WHERE    PRJ_RESOURCES.prID = SRM_RESOURCES.ID
               AND      PRJ_RESOURCES.prID = {@team.prResourceID}
            </niku:sql>
            
		   	<niku:sql name="assignment">
               SELECT   PRAssignment.*
               FROM     PRAssignment, PRTask
               WHERE    PRTask.prProjectID = {@team.prProjectID}
               AND      PRAssignment.prResourceID = {@team.prResourceID}
               AND      PRAssignment.prTaskID = PRTask.prID
               AND      PRAssignment.prEstPattern = 1
		   	</niku:sql>

      		<niku:for-each select="project">
   
      		    <niku:for-each select="resource">

                  <niku:variable name="prName" value="{@resource.FULL_NAME}"/>
                  <niku:variable name="email" value="{@resource.EMAIL}"/>
                  
      		      <niku:sql name="calendar">
                     SELECT   PRCalendar.*
                     FROM     PRCalendar
                     WHERE    PRCalendar.prID={@resource.prCalendarID}
      		   	</niku:sql>
      		   	
      		   	<!-- If there are records in this cursor, I know I have a fixed loading pattern -->
                  <niku:variable name="fixedAllocTest" value="false"/>
      		   	<niku:for-each select="assignment">
      		   		<niku:variable name="fixedAllocTest" value="true"/>
      		   	</niku:for-each>
      
      		   	<niku:variable name="reqStatus" value="ID_CLOSED"/>
      		   	<niku:if test="{@team.prStatus = 1}">
      		   		<niku:variable name="reqStatus" value="ID_OPEN"/>
      		   	</niku:if>
      		   	
      		   	<niku:variable name="bookingStatus" value="ID_SOFT"/>
      		   	<niku:if test="{@team.prBooking &gt;= 10}">
      		   		<niku:variable name="bookingStatus" value="ID_HARD"/>
      		   	</niku:if>

                  <niku:variable name="isNLR" value="{boolean(@resource.RESOURCE_TYPE != 0)}"/>
                  
                  <niku:variable name="openForTimeEntry" value="ID_NO"/>
                  <niku:if test="{@team.prIsOpen}">
                     <niku:variable name="openForTimeEntry" value="ID_YES"/>
                  </niku:if>
                  
      	   
      			   <TEAM_MEMBER_OVERVIEW>
      			   	<!--TEAM_LINKS_HREF url="projmgr.getLinks&amp;id={@prID}&amp;table=PRResource"/-->
      		   		<RESOURCE id="{@resource.prID}" name="{$prName}" email="{$email}"/>
      		   		<PROJECT id="{@project.prID}" name="{@project.prName}"/>
      			   	
      			   	<niku:variable name="getAverageAllocation" value="TRUE"/>
      			   	
      			   	<niku:for-each select="calendar">
                        <niku:teamMemberHandler teamCursor="team" resourceCursor="resource" projectCursor="project" calendarCursor="calendar"/>
                        <niku:attribute name="availabilityDefined" value="{$availabilityDefined}"/>
      			   	</niku:for-each>
      			   	
      			   	<SUMMARY caption="ID_PROPERTIES" urlsuffix="editTeamProperties?id={$id}" icon="">
                        <DATA caption="ID_RESOURCE_NAME" value="{$prName}" type="url" url_string="projmgr.getResourceOverview&amp;id={@resource.prID}"/>
                        <DATA caption="ID_START_DATE" value="{$teamStart}" type="date"/>
                        <DATA caption="ID_FINISH_DATE" value="{$teamFinish}" type="date"/>
                        <niku:if test="{$availabilityDefined}">
                           <DATA caption="ID_DEFAULT_PCT_ALLOCATION" value="{$defaultAllocation + '%'}" type="percent"/>
                           <niku:if test="{$averageAllocation != null and $averageAllocation != ''}">
                              <DATA caption="ID_AVERAGE_PCT_ALLOCATION" value="{$averageAllocation + '%'}" type="percent"/>
                           </niku:if>
                        </niku:if>
                        
                        <!-- if requisitions is enabled do not display the request status -->
                        <niku:if test="{$enableAdvResReqs = 'false'}">
                           <DATA caption="ID_REQUEST_STATUS" value="{$reqStatus}" type="caption"/>
                        </niku:if>
      
                        <DATA caption="ID_BOOKING_STATUS" value="{$bookingStatus}" type="caption"/>
                        <DATA caption="ID_OPEN_FOR_TIME_ENTRY" value="{$openForTimeEntry}" type="caption"/>
                        <niku:if test="{$bottomUpMode != null and $bottomUpMode != ''}">
                            <niku:if test="{$fixedAllocTest}">
                               <DATA caption="ID_LOAD_PATTERN" value="ID_FIXED" type="caption"/>
                               <niku:else>
                                  <DATA caption="ID_LOAD_PATTERN" value="ID_OTHER" type="caption"/>
                               </niku:else>
                            </niku:if>
                        </niku:if>
      			   	</SUMMARY>
      			   	
                     <niku:if test="{$availabilityDefined}">
         					<VIEW object="SegmentList" urlsuffix="getSegmentList?id={$id}">
         						<FIELD name="prStart" type="date" caption="startDate"/>
         						<FIELD name="prFinish" type="date" caption="finishDate" pmDate="true"/>
         						<FIELD name="pctAlloc" type="percent" caption="pctAlloc" decimals="2">
         						    <PARENS type="percent"/>
         						</FIELD>
         					</VIEW>
         		   		<niku:variable name="getAverageAllocation" value=""/>
         		   		<niku:teamMemberHandler teamCursor="team" resourceCursor="resource" projectCursor="project"/>
                     </niku:if>
                  
                     <!-- Link List Component-->
                     <niku:variable name="table" value="PRResource"/>
                     <niku:variable name="id" value="{@resource.prID}"/>
                     <niku:include href="linkListComponent.xql"/>
                     <niku:variable name="id" value="{@team.prID}"/>
      
      		   	</TEAM_MEMBER_OVERVIEW>
      	
      		   	</niku:for-each>
      		   </niku:for-each>   
   
          </niku:for-each>
   		   
      </niku:if>  <!-- end check for records -->

</niku:template>